import {FC, useState} from "react";
import {Image, View} from "@tarojs/components";
import styles from "./home.module.scss";
import Adware from "@/pages/home/components/adware";
import Feature from "@/pages/home/components/feature";
import FeatureRecommended from "@/pages/home/components/feature_recommended";
import CurRecommended from "@/pages/home/components/curRecommended";
import MyButton from "@/components/button/MyButton";
import {Profile} from "@/store";
import Taro from "@tarojs/taro";
import {HomeApi, HomeData} from "@/api";
import logo from '@/static/img/logo.png'
import Spin from "@/components/spinner";


const Home: FC = () => {
  const globalData = Taro.getApp().globalData
  const {bottom, top} = Taro.getMenuButtonBoundingClientRect()
  const {token} = Profile.useContainer()
  const [data, setData] = useState<null | HomeData>(null)
  const [enable, setEnable] = useState(true)
  const titleBarHeight = bottom + top - (globalData.statusBarHeight * 2)

  function unLogin() {
    Taro.clearStorage()
    Taro.navigateTo({url: '/pages/login/login'})
  }

  Taro.useLoad(() => {
    HomeApi.home().then(res => {
      setData(res)
    })
    setTimeout(() => {
      setEnable(false)
    }, 300)
  })

  return (
    <View className={styles.content} style={{paddingTop: `${globalData.statusBarHeight + 60}px`}}>
      <Spin enable={enable} overlay/>
      <View className={styles.header}
            style={{padding: `${globalData.statusBarHeight + 5}px 0 5px 20rpx`, height: `${titleBarHeight - 10}px`}}>
        <Image style={{width: `${titleBarHeight - 10}px`, height: `${titleBarHeight - 10}px`}}
               src={logo}
               mode='aspectFit'/>
      </View>
      <Adware data={data?.adverts || []} only_flag='routine_home_top_banner' width={710}/>
      <Feature/>
      <FeatureRecommended
        illness={data?.illness.list || []}
        health={data?.health || []}
        brand={data?.brand.list || []}
        skill={data?.skill || []}
      />
      <Adware data={data?.adverts || []} only_flag='routine_home_recommend_banner' width={710}/>
      {data && <CurRecommended/>}
      {
        !token && <View className={styles.tipsLogin} onClick={unLogin}>
          <View>登录后享受更多服务~</View>
          <MyButton fillet size='mini'>立即登录</MyButton>
        </View>
      }
    </View>
  )
}

export default Home
