import {Input, View, Text} from "@tarojs/components";
import {FC, useState} from "react";
import { AtIcon } from 'taro-ui'
import styles from './index.module.scss'
import Taro from "@tarojs/taro";
import { useReady, useDidShow } from '@tarojs/taro'


const Search:FC = () => {
  const [value, setValue] = useState('')
  const [recentSearch, setRecentSearch] = useState<string[]>([])
  const [hotSearch,setHotSearch] = useState<any[]>([])

  useReady(()=>{
    console.log('onReady')
  })
  useDidShow(()=>{
    getRecentSearch()
  })

  function inpFn(e){
    setValue(e.detail.value)
  }

  function clearSearch(){
    Taro.removeStorageSync('recentSearch')
    getRecentSearch()
  }

  function getRecentSearch () {
    setRecentSearch(Taro.getStorageSync('recentSearch'))
  }
  function getSearchItem(value) {
    Taro.navigateTo({
      url:`/pages/preview/search/list/index?name=${value}`
    })
  }

 function searchInput(){
   if (value === "") return;
   getSearchItem(value)
   //记录最近搜索
   let recentSearch = Taro.getStorageSync('recentSearch') || [];
   recentSearch.unshift(value);
   Taro.setStorageSync('recentSearch', [...new Set(recentSearch)])
 }

  return (
    <View className="flex flex-column">
        <View className={styles.searchBox}>
          <AtIcon value='search' size='20' color='#ccc'></AtIcon>
          <Input className={styles.input} placeholder="输入关键字搜索课程" type={'text'} confirmType={'search'} onInput={inpFn} onConfirm={searchInput} />
        </View>

      {
        recentSearch.length >= 1 &&
        <>
          <View className={styles.titleBox} >
            <Text className={styles.title}>最近搜索</Text>
            <AtIcon onClick={clearSearch} value='trash' size='16' color='#909795'></AtIcon>
          </View>
            <View className={styles.contentBox}>
              {
                recentSearch.length &&
                recentSearch?.map(d =>
                  <View className={styles.items}>
                    <View onClick={()=>{getSearchItem(d)}} className="font-28" >{d}</View>
                  </View>)
              }
            </View>
        </>
      }
      {
        hotSearch.length >= 1 &&
        <>
          <View className={`flex justify-between ${styles.titleBox}`} >

            <Text className="font-32 fwb">热门搜索</Text>
          </View>
          <View className="wid100 pt-3 pl-3 box-b">
            <View className="wid100 flex flex-wrap">
              {
                hotSearch.length &&
                hotSearch.map(d =>
                  <View className="py-1 px-2 rounded-40 mr-2 mb-2 bg-warning text-white">
                    <View onClick={()=>{getSearchItem(d)}} className="font-28" >{d}</View>
                  </View>)
              }
            </View>
          </View>
        </>
      }

    </View>
  )
}
export default Search
